Welcome to padepy!
==================

padepy is a Python library for Padé approximation calculation with infinite (algebric) and finite (floating) precision. The current version supports two methods: a direct algorithm, in Frobenius sense, and Baker’s recursive algorithm.

Documentation
-------------

The official documentation is hosted by Read the Docs: https://padepy.readthedocs.io/en/latest/


